=========
 Changes
=========


1.5.0 (2018-09-11)
==================

- Add support for zope.schema 4.7.0; drop support for older versions.


1.4.2 (2018-09-10)
==================

- Fix the ``repr`` of ``nti.schema.interfaces.InvalidValue``. See
  `issue 26 <https://github.com/NextThought/nti.schema/issues/26>`_.

- ``nti.schema.jsonschema`` turns more abstract field types into
  concrete types. See `issue 29 <https://github.com/NextThought/nti.schema/issues/29>`_.

1.4.1 (2018-09-10)
==================

- Make ``nti.schema.interfaces.InvalidValue`` a class again. It is
  deprecated. See `issue 24 <https://github.com/NextThought/nti.schema/issues/24>`_.


1.4.0 (2018-09-10)
==================

- Drop support for ``dm.zope.schema`` fields, in particular the
  ``Object`` field. The validation performed by ``zope.schema.Object``
  is much improved.

- Drop support for ``zope.schema`` older than 4.6.1.

- Deprecate ``nti.schema.field.Number``.

- Add support for Python 3.7.

1.3.3 (2018-09-07)
==================

- Minor fix for changes in zope.schema 4.6.0 (import
  ``BeforeObjectAssignedEvent`` from its new, but still private, location).


1.3.2 (2017-10-24)
==================

- Depend on zope.deferredimport >= 4.2.1 to be able to generate Sphinx
  documentation.
- Clean up code to match PEP8.


1.3.1 (2017-10-18)
==================

- Fix an ``UnboundLocalError`` on Python 3 in the ``Variant`` field.
  See `issue 14 <https://github.com/NextThought/nti.schema/issues/14>`_.


1.3.0 (2017-07-06)
==================

- Drop the Python 2 dependency on ``plone.i18n`` in favor of the new
  library ``nti.i18n``, which supports Python 3. If ``plone.i18n`` is
  installed, it *should not* be configured (ZCML), but its utility
  objects can be looked up by either interface.


1.2.0 (2017-05-17)
==================

- Remove use of ``unicode_literals``.

- Add support for Python 3.6.

- The ``SchemaConfigured`` constructor doesn't hide errors when
  checking for properties on Python 2. See `issue 11
  <https://github.com/NextThought/nti.schema/issues/11>`_.


1.1.3 (2017-01-17)
==================

- Add info to minLength validation message.


1.1.2 (2016-09-14)
==================

- Add ``Acquisition`` and ``zope.event`` as install dependencies.
  Previously they were only pulled in via the ``test`` extra.


1.1.1 (2016-09-08)
==================

- Substantial speedups to the hash functions generated by ``EqHash``.
- Substantial speedups to the equality functions generated by ``EqHash``.

1.1.0 (2016-07-29)
==================
- Add support for Python 3. *Note* the countries vocabulary will not
  be complete on Python 3.
- Drop the ``dolmen.builtins`` dependency.
- Drop the ``dm.zope.schema`` dependency.
- The ``plone.i18n`` dependency is Python 2 only (and can even be
  removed).
- The matchers in ``nti.schema.testing`` have been moved to
  ``nti.testing.matchers``.
- Using ``AdaptingFieldProperty`` will now raise the more specific
  ``SchemaNotProvided`` error instead of a ``TypeError`` if adapting
  the value fails.
- ``EqHash`` has moved from ``nti.schema.schema`` to
  ``nti.schema.eqhash``. A compatibility shim remains.
